@@ -1,10 +1,10 @@
 import * as React from 'react';
-import App from '../App';
+import Spawner from '../Spawner';
 import { shallow } from 'enzyme';
 
-describe('App test', () => {
+describe('Spawner test', () => {
   it('should render a basic component', () => {
-    const component = shallow(<App />);
+    const component = shallow(<Spawner />);
     expect(component.html()).toMatchSnapshot('basic');
   });
 });
